@@ -17,4 +17,4 @@ class Tweet:
 		return f"tweet id: {id}"
 		
 def get_tweet(id:int):
-	return Tweet(id:int)
+	return Tweet(id)
